@@ -479,14 +479,14 @@ class ConfigWidget(ConfigWidgetBase, Ui_Form):
         r('tags_browser_collapse_at', gprefs)
         r('tag_browser_dont_collapse', gprefs, setting=CommaSeparatedList)
 
-        choices = set([k for k in db.field_metadata.all_field_keys()
+        choices = {k for k in db.field_metadata.all_field_keys()
                 if (db.field_metadata[k]['is_category'] and (
                     db.field_metadata[k]['datatype'] in ['text', 'series', 'enumeration'
                     ]) and not db.field_metadata[k]['display'].get('is_names', False)) or (
                     db.field_metadata[k]['datatype'] in ['composite'
-                    ] and db.field_metadata[k]['display'].get('make_category', False))])
-        choices -= set(['authors', 'publisher', 'formats', 'news', 'identifiers'])
-        choices |= set(['search'])
+                    ] and db.field_metadata[k]['display'].get('make_category', False))}
+        choices -= {'authors', 'publisher', 'formats', 'news', 'identifiers'}
+        choices |= {'search'}
         self.opt_categories_using_hierarchy.update_items_cache(choices)
         r('categories_using_hierarchy', db.prefs, setting=CommaSeparatedList,
           choices=sorted(list(choices), key=sort_key))
